@@ -1,3 +1,5 @@
+# 2011-06-13 CJS returned bayesian p-values
+
 PredictivePosteriorPlot.TSPDE.WHCH <- function( discrep  ) {
 #   Given the discrepancy measures, creates a set of panel plots.
 #   It is assumed that the bp has 12 columns
@@ -13,6 +15,8 @@ titles <- c("Freeman-Tukey for m2",
             "Freeman-Tukey for u2.N", 
             "Total Freeman-Tukey")
 
+saved_p_values <- rep(NA, length(titles))
+
 for(i in 1:4){
   screen(i)
   par(cex=.5)
@@ -27,6 +31,7 @@ for(i in 1:4){
 
   ## Compute Bayesian p-value
   p.value <- sum(discrep[,2*i-1]<discrep[,2*i])/nrow(discrep)
+  saved_p_values[i] <- p.value
   
   ## Add p-value to plot
   x.loc <- mean(lims)
@@ -37,4 +42,6 @@ for(i in 1:4){
        cex=1.5, adj=c(0,0))  
 }
 close.screen(all=TRUE)     # exit from plots  
+gof <- data.frame(statistic=titles, p.value=saved_p_values)
+gof
 }
