@@ -1,3 +1,5 @@
+# 2011-06-13 CJS returned bayesian p-values
+
 PredictivePosteriorPlot.TSPNDE <- function( discrep  ) {
 #   Given the discrepancy measures, creates a set of panel plots.
 #   It is assumed that the bp has 12 columns
@@ -15,6 +17,7 @@ titles <- c("Freeman-Tukey for m2",
             "Deviance for u2",
             "Total Freeman-Tukey",
             "Total deviance")
+saved_p_values <- rep(NA, length(titles))
 
 for(i in 1:6){
   screen(i)
@@ -33,6 +36,7 @@ for(i in 1:6){
 
   ## Compute Bayesian p-value
   p.value <- sum(discrep[,2*i-1]<discrep[,2*i])/nrow(discrep)
+  saved_p_values[i] <- p.value
 
   ## Add p-value to plot
   x.loc <- mean(lims)
@@ -43,4 +47,6 @@ for(i in 1:6){
        cex=1.5, adj=c(0,0))  
 }
 close.screen(all=TRUE)     # exit from plots  
+gof <- data.frame(statistic=titles, p.value=saved_p_values)
+gof
 }
